@@ -16,12 +16,17 @@ async def async_normalize_erc20_quantity(
 ) -> float:
     """convert raw erc20 quantity by adjusting radix by (10 ** decimals)"""
 
+    if quantity == 0:
+        return 0
+
     # get decimals
     if decimals is None:
         if token is None:
             raise Exception('must specify token or decimals')
         decimals = await erc20_metadata.async_get_erc20_decimals(
-            token, provider=provider, block=block,
+            token,
+            provider=provider,
+            block=block,
         )
     else:
         decimals = int(decimals)
@@ -38,6 +43,9 @@ async def async_normalize_erc20_quantities(
     block: spec.BlockNumberReference = 'latest',
 ) -> list[float]:
 
+    if all(quantity == 0 for quantity in quantities):
+        return quantities
+
     if decimals is None:
         if token is None:
             raise Exception('must specify token or decimals')
@@ -55,11 +63,26 @@ async def async_normalize_erc20_quantities(
 async def async_normalize_erc20s_quantities(
     quantities: typing.Sequence[typing.SupportsInt],
     tokens: typing.Optional[typing.Sequence[spec.ERC20Address]] = None,
-    provider: spec.ProviderSpec = None,
     decimals: typing.Optional[typing.Sequence[typing.SupportsInt]] = None,
     block: spec.BlockNumberReference = 'latest',
+    provider: spec.ProviderSpec = None,
 ) -> list[float]:
 
+    # take subset of non zero values
+    mask = [quantity != 0 for quantity in quantities]
+    any_zero = not all(mask)
+    if any_zero:
+        old_quantities = quantities
+        quantities = [
+            quantity for quantity, nonzero in zip(quantities, mask) if nonzero
+        ]
+        if tokens is not None:
+            tokens = [token for token, nonzero in zip(tokens, mask) if nonzero]
+        if decimals is not None:
+            decimals = [
+                decimal for decimal, nonzero in zip(decimals, mask) if nonzero
+            ]
+
     if decimals is None:
         if tokens is None:
             raise Exception('must specify tokens or decimals')
@@ -74,6 +97,18 @@ async def async_normalize_erc20s_quantities(
     if len(use_decimals) != len(quantities):
         raise Exception('number of quantities must match number of decimals')
 
+    # put back in zero values
+    if any_zero:
+        quantities = old_quantities
+        new_use_decimals = []
+        use_decimals_iterator = iter(use_decimals)
+        for nonzero in mask:
+            if nonzero:
+                new_use_decimals.append(next(use_decimals_iterator))
+            else:
+                new_use_decimals.append(1)
+        use_decimals = new_use_decimals
+
     return [
         quantity / (10 ** decimal)
         for quantity, decimal in zip(quantities, use_decimals)
@@ -82,12 +117,28 @@ async def async_normalize_erc20s_quantities(
 
 async def async_normalize_erc20_quantities_by_block(
     quantities: typing.Sequence[typing.SupportsInt],
+    blocks: typing.Iterable[spec.BlockNumberReference],
     token: typing.Optional[spec.ERC20Address] = None,
     decimals: typing.Optional[list[typing.SupportsInt]] = None,
     provider: spec.ProviderSpec = None,
-    blocks: typing.Optional[typing.Iterable[spec.BlockNumberReference]] = None,
 ) -> list[float]:
 
+    # take subset of non zero values
+    mask = [quantity != 0 for quantity in quantities]
+    any_zero = not all(mask)
+    if any_zero:
+        old_quantities = quantities
+        quantities = [
+            quantity for quantity, nonzero in zip(quantities, mask) if nonzero
+        ]
+        blocks = [
+            block for block, nonzero in zip(blocks, mask) if nonzero
+        ]
+        if decimals is not None:
+            decimals = [
+                decimal for decimal, nonzero in zip(decimals, mask) if nonzero
+            ]
+
     if decimals is None:
         if token is None:
             raise Exception('must specify token or decimals')
@@ -102,88 +153,19 @@ async def async_normalize_erc20_quantities_by_block(
     if len(use_decimals) != len(quantities):
         raise Exception('number of quantities must match number of decimals')
 
+    if any_zero:
+        quantities = old_quantities
+        new_use_decimals = []
+        use_decimals_iterator = iter(use_decimals)
+        for nonzero in mask:
+            if nonzero:
+                new_use_decimals.append(next(use_decimals_iterator))
+            else:
+                new_use_decimals.append(1)
+        use_decimals = new_use_decimals
+
     return [
         quantity / (10 ** decimal)
         for quantity, decimal in zip(quantities, use_decimals)
     ]
 
-
-# async def async_normalize_erc20_quantities(
-#     quantities: typing.Sequence[typing.SupportsInt],
-#     token: typing.Optional[spec.ERC20Address] = None,
-#     tokens: typing.Optional[typing.Sequence[spec.ERC20Address]] = None,
-#     provider: spec.ProviderSpec = None,
-#     decimals: typing.Union[
-#         typing.SupportsInt,
-#         typing.Sequence[typing.SupportsInt],
-#     ] = None,
-#     block: typing.Optional[spec.BlockNumberReference] = None,
-#     blocks: typing.Optional[typing.Iterable[spec.BlockNumberReference]] = None,
-# ) -> list[float]:
-#     """convert raw erc20 quantities by adjusting radix by (10 ** decimals)"""
-
-#     n = len(quantities)
-
-#     # parse inputs
-#     if token is None and tokens is None:
-#         raise Exception('must specify token or tokens')
-#     if tokens is not None and len(tokens) != n:
-#         raise Exception('number of tokens must match number of quantities')
-#     if (
-#         decimals is not None
-#         and isinstance(decimals, typing.Sequence)
-#         and len(decimals) is not None
-#     ):
-#         raise Exception('number of decimals must match number of quantities')
-
-#     # query decimals if need be
-#     if decimals is None:
-
-#         if token is not None:
-
-#             if blocks is not None:
-#                 decimals = await erc20_metadata.async_get_erc20_decimals_by_block(
-#                     token=token,
-#                     provider=provider,
-#                     blocks=blocks,
-#                 )
-
-#             else:
-
-#                 if block is None:
-#                     block = 'latest'
-#                 decimals = await erc20_metadata.async_get_erc20_decimals(
-#                     token=token,
-#                     provider=provider,
-#                     block=block,
-#                 )
-
-#         elif tokens is not None:
-
-#             if block is None:
-#                 block = 'latest'
-#             decimals = await erc20_metadata.async_get_erc20s_decimals(
-#                 tokens=tokens,
-#                 provider=provider,
-#                 block=block,
-#             )
-
-#         else:
-#             raise Exception('must specify token or tokens')
-
-#     # convert decimals to list of int
-#     if isinstance(decimals, typing.Iterable):
-#         decimals = [int(decimal) for decimal in decimals]
-#     elif isinstance(decimals, typing.SupportsInt):
-#         decimals = int(decimals)
-#         decimals = [decimals for i in range(n)]
-#     else:
-#         raise Exception('unknown decimals format')
-#     decimals = typing.cast(list[int], decimals)
-
-#     # normalize
-#     return [
-#         quantity / (10 ** decimal)
-#         for quantity, decimal in zip(quantities, decimals)
-#     ]
-
