@@ -19,6 +19,11 @@ async def async_get_eth_total_supply():
         return int(result['result'])
 
 
+#
+# # balances
+#
+
+
 @typing.overload
 async def async_get_eth_balance(
     address: spec.Address,
@@ -94,3 +99,42 @@ async def async_get_eth_balance_by_block(
 
     return await asyncio.gather(*coroutines)
 
+
+@typing.overload
+async def async_get_eth_balance_of_addresses(
+    addresses: spec.Address,
+    block: typing.Sequence[spec.BlockNumberReference],
+    normalize: typing.Literal[False],
+    provider: typing.Optional[spec.ProviderSpec] = None,
+) -> list[int]:
+    ...
+
+
+@typing.overload
+async def async_get_eth_balance_of_addresses(
+    addresses: spec.Address,
+    block: typing.Sequence[spec.BlockNumberReference],
+    normalize: typing.Literal[True] = True,
+    provider: typing.Optional[spec.ProviderSpec] = None,
+) -> list[float]:
+    ...
+
+
+async def async_get_eth_balance_of_addresses(
+    addresses: typing.Sequence[spec.Address],
+    normalize: bool = True,
+    provider: typing.Optional[spec.ProviderSpec] = None,
+    block: typing.Optional[spec.BlockNumberReference] = None,
+) -> typing.Union[list[int], list[float]]:
+
+    balances = await rpc.async_batch_eth_get_balance(
+        addresses=addresses,
+        provider=provider,
+        block_number=block,
+    )
+
+    if normalize:
+        balances = [balance / 1e18 for balance in balances]
+
+    return balances
+
