@@ -1,6 +1,7 @@
 # https://docs.chain.link/docs/faq/
 
 import typing
+from typing_extensions import TypedDict
 
 from ctc import spec
 
@@ -8,13 +9,13 @@ from ctc import spec
 _FeedReference = typing.Union[spec.Address, str]
 
 
-class FeedRoundData(typing.TypedDict):
+class FeedRoundData(TypedDict):
     answer: int
     round_id: int
     timestamp: int
 
 
-class FeedRoundDataNormalized(typing.TypedDict):
+class FeedRoundDataNormalized(TypedDict):
     answer: float
     round_id: int
     timestamp: int
